# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.2-v202604030243-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class TableSearchSourceV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'condition_stats': 'list[ConditionTableStatInputForTableV1]',
        'properties_to_include': 'list[PropertiesForItemUUIDColumn]',
        'search_input': 'TableSearchInputV1'
    }

    attribute_map = {
        'condition_stats': 'conditionStats',
        'properties_to_include': 'propertiesToInclude',
        'search_input': 'searchInput'
    }

    def __init__(self, condition_stats=None, properties_to_include=None, search_input=None):
        """
        TableSearchSourceV1 - a model defined in Swagger
        """

        self._condition_stats = None
        self._properties_to_include = None
        self._search_input = None

        if condition_stats is not None:
          self.condition_stats = condition_stats
        if properties_to_include is not None:
          self.properties_to_include = properties_to_include
        if search_input is not None:
          self.search_input = search_input

    @property
    def condition_stats(self):
        """
        Gets the condition_stats of this TableSearchSourceV1.
        The list of statistics to calculate for the conditions/metrics

        :return: The condition_stats of this TableSearchSourceV1.
        :rtype: list[ConditionTableStatInputForTableV1]
        """
        return self._condition_stats

    @condition_stats.setter
    def condition_stats(self, condition_stats):
        """
        Sets the condition_stats of this TableSearchSourceV1.
        The list of statistics to calculate for the conditions/metrics

        :param condition_stats: The condition_stats of this TableSearchSourceV1.
        :type: list[ConditionTableStatInputForTableV1]
        """

        self._condition_stats = condition_stats

    @property
    def properties_to_include(self):
        """
        Gets the properties_to_include of this TableSearchSourceV1.
        Additional properties to fetch per row that will be added as additional columns. The following columns can be used:  item id,  Asset,  Path,  Value UOM,  Datasource,  Source Column ID 

        :return: The properties_to_include of this TableSearchSourceV1.
        :rtype: list[PropertiesForItemUUIDColumn]
        """
        return self._properties_to_include

    @properties_to_include.setter
    def properties_to_include(self, properties_to_include):
        """
        Sets the properties_to_include of this TableSearchSourceV1.
        Additional properties to fetch per row that will be added as additional columns. The following columns can be used:  item id,  Asset,  Path,  Value UOM,  Datasource,  Source Column ID 

        :param properties_to_include: The properties_to_include of this TableSearchSourceV1.
        :type: list[PropertiesForItemUUIDColumn]
        """

        self._properties_to_include = properties_to_include

    @property
    def search_input(self):
        """
        Gets the search_input of this TableSearchSourceV1.

        :return: The search_input of this TableSearchSourceV1.
        :rtype: TableSearchInputV1
        """
        return self._search_input

    @search_input.setter
    def search_input(self, search_input):
        """
        Sets the search_input of this TableSearchSourceV1.

        :param search_input: The search_input of this TableSearchSourceV1.
        :type: TableSearchInputV1
        """
        if search_input is None:
            raise ValueError("Invalid value for `search_input`, must not be `None`")

        self._search_input = search_input

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TableSearchSourceV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.2-v202604030243-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class TableDefinitionPreviewInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _bypass_model_controlled_restriction: Optional[bool]
    _column_definitions: ColumnDefinitionBulkEditInputListV1
    _rows: Optional[List[RowId]]


    def __init__(
        self,
        bypass_model_controlled_restriction: Optional[bool] = None,
        column_definitions: Optional[ColumnDefinitionBulkEditInputListV1] = None,
        rows: Optional[List[RowId]] = None,
    ) -> None: ...

    @property
    def bypass_model_controlled_restriction(self) -> Optional[bool]: ...

    @bypass_model_controlled_restriction.setter
    def bypass_model_controlled_restriction(self, bypass_model_controlled_restriction: Optional[bool]) -> None: ...

    @property
    def column_definitions(self) -> ColumnDefinitionBulkEditInputListV1: ...

    @column_definitions.setter
    def column_definitions(self, column_definitions: ColumnDefinitionBulkEditInputListV1) -> None: ...

    @property
    def rows(self) -> Optional[List[RowId]]: ...

    @rows.setter
    def rows(self, rows: Optional[List[RowId]]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.2-v202604030243-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class LabelOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'archived': 'bool',
        'archived_at': 'str',
        'archiver_id': 'str',
        'category_id': 'str',
        'icon': 'str',
        'id': 'str',
        'name': 'str',
        'parent_id': 'str'
    }

    attribute_map = {
        'archived': 'archived',
        'archived_at': 'archivedAt',
        'archiver_id': 'archiverId',
        'category_id': 'categoryId',
        'icon': 'icon',
        'id': 'id',
        'name': 'name',
        'parent_id': 'parentId'
    }

    def __init__(self, archived=None, archived_at=None, archiver_id=None, category_id=None, icon=None, id=None, name=None, parent_id=None):
        """
        LabelOutputV1 - a model defined in Swagger
        """

        self._archived = None
        self._archived_at = None
        self._archiver_id = None
        self._category_id = None
        self._icon = None
        self._id = None
        self._name = None
        self._parent_id = None

        if archived is not None:
          self.archived = archived
        if archived_at is not None:
          self.archived_at = archived_at
        if archiver_id is not None:
          self.archiver_id = archiver_id
        if category_id is not None:
          self.category_id = category_id
        if icon is not None:
          self.icon = icon
        if id is not None:
          self.id = id
        if name is not None:
          self.name = name
        if parent_id is not None:
          self.parent_id = parent_id

    @property
    def archived(self):
        """
        Gets the archived of this LabelOutputV1.
        Whether this label is archived

        :return: The archived of this LabelOutputV1.
        :rtype: bool
        """
        return self._archived

    @archived.setter
    def archived(self, archived):
        """
        Sets the archived of this LabelOutputV1.
        Whether this label is archived

        :param archived: The archived of this LabelOutputV1.
        :type: bool
        """
        if archived is None:
            raise ValueError("Invalid value for `archived`, must not be `None`")

        self._archived = archived

    @property
    def archived_at(self):
        """
        Gets the archived_at of this LabelOutputV1.
        If archived, the time when this label was archived

        :return: The archived_at of this LabelOutputV1.
        :rtype: str
        """
        return self._archived_at

    @archived_at.setter
    def archived_at(self, archived_at):
        """
        Sets the archived_at of this LabelOutputV1.
        If archived, the time when this label was archived

        :param archived_at: The archived_at of this LabelOutputV1.
        :type: str
        """

        self._archived_at = archived_at

    @property
    def archiver_id(self):
        """
        Gets the archiver_id of this LabelOutputV1.
        If archived, the ID of the user who archived this label

        :return: The archiver_id of this LabelOutputV1.
        :rtype: str
        """
        return self._archiver_id

    @archiver_id.setter
    def archiver_id(self, archiver_id):
        """
        Sets the archiver_id of this LabelOutputV1.
        If archived, the ID of the user who archived this label

        :param archiver_id: The archiver_id of this LabelOutputV1.
        :type: str
        """

        self._archiver_id = archiver_id

    @property
    def category_id(self):
        """
        Gets the category_id of this LabelOutputV1.
        ID of the label category

        :return: The category_id of this LabelOutputV1.
        :rtype: str
        """
        return self._category_id

    @category_id.setter
    def category_id(self, category_id):
        """
        Sets the category_id of this LabelOutputV1.
        ID of the label category

        :param category_id: The category_id of this LabelOutputV1.
        :type: str
        """

        self._category_id = category_id

    @property
    def icon(self):
        """
        Gets the icon of this LabelOutputV1.
        If present, the icon for the label

        :return: The icon of this LabelOutputV1.
        :rtype: str
        """
        return self._icon

    @icon.setter
    def icon(self, icon):
        """
        Sets the icon of this LabelOutputV1.
        If present, the icon for the label

        :param icon: The icon of this LabelOutputV1.
        :type: str
        """

        self._icon = icon

    @property
    def id(self):
        """
        Gets the id of this LabelOutputV1.
        ID of the label

        :return: The id of this LabelOutputV1.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this LabelOutputV1.
        ID of the label

        :param id: The id of this LabelOutputV1.
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """
        Gets the name of this LabelOutputV1.
        Name of the label

        :return: The name of this LabelOutputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this LabelOutputV1.
        Name of the label

        :param name: The name of this LabelOutputV1.
        :type: str
        """

        self._name = name

    @property
    def parent_id(self):
        """
        Gets the parent_id of this LabelOutputV1.
        If present, the ID of the parent label

        :return: The parent_id of this LabelOutputV1.
        :rtype: str
        """
        return self._parent_id

    @parent_id.setter
    def parent_id(self, parent_id):
        """
        Sets the parent_id of this LabelOutputV1.
        If present, the ID of the parent label

        :param parent_id: The parent_id of this LabelOutputV1.
        :type: str
        """

        self._parent_id = parent_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, LabelOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.2-v202604030243-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ConfigFieldV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _allow_null: bool
    _description: Optional[str]
    _name: Optional[str]
    _path: str
    _type: str
    _unique_key: str
    _value: Optional[Any]


    def __init__(
        self,
        allow_null: Optional[bool] = None,
        description: Optional[str] = None,
        name: Optional[str] = None,
        path: Optional[str] = None,
        type: Optional[str] = None,
        unique_key: Optional[str] = None,
        value: Optional[Any] = None,
    ) -> None: ...

    @property
    def allow_null(self) -> bool: ...

    @allow_null.setter
    def allow_null(self, allow_null: bool) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def name(self) -> Optional[str]: ...

    @name.setter
    def name(self, name: Optional[str]) -> None: ...

    @property
    def path(self) -> str: ...

    @path.setter
    def path(self, path: str) -> None: ...

    @property
    def type(self) -> str: ...

    @type.setter
    def type(self, type: str) -> None: ...

    @property
    def unique_key(self) -> str: ...

    @unique_key.setter
    def unique_key(self, unique_key: str) -> None: ...

    @property
    def value(self) -> Optional[Any]: ...

    @value.setter
    def value(self, value: Optional[Any]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.2-v202604030243-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class IndexingParametersInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'source_agent_name': 'str',
        'sync_mode': 'str'
    }

    attribute_map = {
        'source_agent_name': 'sourceAgentName',
        'sync_mode': 'syncMode'
    }

    def __init__(self, source_agent_name=None, sync_mode=None):
        """
        IndexingParametersInputV1 - a model defined in Swagger
        """

        self._source_agent_name = None
        self._sync_mode = None

        if source_agent_name is not None:
          self.source_agent_name = source_agent_name
        if sync_mode is not None:
          self.sync_mode = sync_mode

    @property
    def source_agent_name(self):
        """
        Gets the source_agent_name of this IndexingParametersInputV1.
        The name of the agent requesting the index.

        :return: The source_agent_name of this IndexingParametersInputV1.
        :rtype: str
        """
        return self._source_agent_name

    @source_agent_name.setter
    def source_agent_name(self, source_agent_name):
        """
        Sets the source_agent_name of this IndexingParametersInputV1.
        The name of the agent requesting the index.

        :param source_agent_name: The source_agent_name of this IndexingParametersInputV1.
        :type: str
        """

        self._source_agent_name = source_agent_name

    @property
    def sync_mode(self):
        """
        Gets the sync_mode of this IndexingParametersInputV1.
        The sync mode. Please use one of: FULL, INCREMENTAL

        :return: The sync_mode of this IndexingParametersInputV1.
        :rtype: str
        """
        return self._sync_mode

    @sync_mode.setter
    def sync_mode(self, sync_mode):
        """
        Sets the sync_mode of this IndexingParametersInputV1.
        The sync mode. Please use one of: FULL, INCREMENTAL

        :param sync_mode: The sync_mode of this IndexingParametersInputV1.
        :type: str
        """

        self._sync_mode = sync_mode

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, IndexingParametersInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.2-v202604030243-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class HierarchyOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'alias_column_id': 'str',
        'description': 'str',
        'effective_permissions': 'PermissionsV1',
        'filter_grouping': 'str',
        'id': 'str',
        'is_archived': 'bool',
        'is_redacted': 'bool',
        'name': 'str',
        'scoped_to': 'str',
        'status_message': 'str',
        'table_definition': 'ItemPreviewV1',
        'table_definition_output': 'TableDefinitionOutputV1',
        'translation_key': 'str',
        'type': 'str',
        'view_columns': 'list[ViewColumnOutputV1]'
    }

    attribute_map = {
        'alias_column_id': 'aliasColumnId',
        'description': 'description',
        'effective_permissions': 'effectivePermissions',
        'filter_grouping': 'filterGrouping',
        'id': 'id',
        'is_archived': 'isArchived',
        'is_redacted': 'isRedacted',
        'name': 'name',
        'scoped_to': 'scopedTo',
        'status_message': 'statusMessage',
        'table_definition': 'tableDefinition',
        'table_definition_output': 'tableDefinitionOutput',
        'translation_key': 'translationKey',
        'type': 'type',
        'view_columns': 'viewColumns'
    }

    def __init__(self, alias_column_id=None, description=None, effective_permissions=None, filter_grouping=None, id=None, is_archived=False, is_redacted=False, name=None, scoped_to=None, status_message=None, table_definition=None, table_definition_output=None, translation_key=None, type=None, view_columns=None):
        """
        HierarchyOutputV1 - a model defined in Swagger
        """

        self._alias_column_id = None
        self._description = None
        self._effective_permissions = None
        self._filter_grouping = None
        self._id = None
        self._is_archived = None
        self._is_redacted = None
        self._name = None
        self._scoped_to = None
        self._status_message = None
        self._table_definition = None
        self._table_definition_output = None
        self._translation_key = None
        self._type = None
        self._view_columns = None

        if alias_column_id is not None:
          self.alias_column_id = alias_column_id
        if description is not None:
          self.description = description
        if effective_permissions is not None:
          self.effective_permissions = effective_permissions
        if filter_grouping is not None:
          self.filter_grouping = filter_grouping
        if id is not None:
          self.id = id
        if is_archived is not None:
          self.is_archived = is_archived
        if is_redacted is not None:
          self.is_redacted = is_redacted
        if name is not None:
          self.name = name
        if scoped_to is not None:
          self.scoped_to = scoped_to
        if status_message is not None:
          self.status_message = status_message
        if table_definition is not None:
          self.table_definition = table_definition
        if table_definition_output is not None:
          self.table_definition_output = table_definition_output
        if translation_key is not None:
          self.translation_key = translation_key
        if type is not None:
          self.type = type
        if view_columns is not None:
          self.view_columns = view_columns

    @property
    def alias_column_id(self):
        """
        Gets the alias_column_id of this HierarchyOutputV1.
        The ID of the column the Hierarchy should use for aliases. If not provided item names will be used for the items in the hierarchy.

        :return: The alias_column_id of this HierarchyOutputV1.
        :rtype: str
        """
        return self._alias_column_id

    @alias_column_id.setter
    def alias_column_id(self, alias_column_id):
        """
        Sets the alias_column_id of this HierarchyOutputV1.
        The ID of the column the Hierarchy should use for aliases. If not provided item names will be used for the items in the hierarchy.

        :param alias_column_id: The alias_column_id of this HierarchyOutputV1.
        :type: str
        """

        self._alias_column_id = alias_column_id

    @property
    def description(self):
        """
        Gets the description of this HierarchyOutputV1.
        Clarifying information or other plain language description of this item

        :return: The description of this HierarchyOutputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this HierarchyOutputV1.
        Clarifying information or other plain language description of this item

        :param description: The description of this HierarchyOutputV1.
        :type: str
        """

        self._description = description

    @property
    def effective_permissions(self):
        """
        Gets the effective_permissions of this HierarchyOutputV1.

        :return: The effective_permissions of this HierarchyOutputV1.
        :rtype: PermissionsV1
        """
        return self._effective_permissions

    @effective_permissions.setter
    def effective_permissions(self, effective_permissions):
        """
        Sets the effective_permissions of this HierarchyOutputV1.

        :param effective_permissions: The effective_permissions of this HierarchyOutputV1.
        :type: PermissionsV1
        """

        self._effective_permissions = effective_permissions

    @property
    def filter_grouping(self):
        """
        Gets the filter_grouping of this HierarchyOutputV1.
        The logical filter grouping for column filters. Represents an expression on view column filter identifiers using AND/OR operators.  Parentheses may be present to dictate operation ordering. If filterGrouping is not present, all filters will be applied with the AND operator.

        :return: The filter_grouping of this HierarchyOutputV1.
        :rtype: str
        """
        return self._filter_grouping

    @filter_grouping.setter
    def filter_grouping(self, filter_grouping):
        """
        Sets the filter_grouping of this HierarchyOutputV1.
        The logical filter grouping for column filters. Represents an expression on view column filter identifiers using AND/OR operators.  Parentheses may be present to dictate operation ordering. If filterGrouping is not present, all filters will be applied with the AND operator.

        :param filter_grouping: The filter_grouping of this HierarchyOutputV1.
        :type: str
        """

        self._filter_grouping = filter_grouping

    @property
    def id(self):
        """
        Gets the id of this HierarchyOutputV1.
        The ID that can be used to interact with the item

        :return: The id of this HierarchyOutputV1.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this HierarchyOutputV1.
        The ID that can be used to interact with the item

        :param id: The id of this HierarchyOutputV1.
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")

        self._id = id

    @property
    def is_archived(self):
        """
        Gets the is_archived of this HierarchyOutputV1.
        Whether item is archived

        :return: The is_archived of this HierarchyOutputV1.
        :rtype: bool
        """
        return self._is_archived

    @is_archived.setter
    def is_archived(self, is_archived):
        """
        Sets the is_archived of this HierarchyOutputV1.
        Whether item is archived

        :param is_archived: The is_archived of this HierarchyOutputV1.
        :type: bool
        """

        self._is_archived = is_archived

    @property
    def is_redacted(self):
        """
        Gets the is_redacted of this HierarchyOutputV1.
        Whether item is redacted

        :return: The is_redacted of this HierarchyOutputV1.
        :rtype: bool
        """
        return self._is_redacted

    @is_redacted.setter
    def is_redacted(self, is_redacted):
        """
        Sets the is_redacted of this HierarchyOutputV1.
        Whether item is redacted

        :param is_redacted: The is_redacted of this HierarchyOutputV1.
        :type: bool
        """

        self._is_redacted = is_redacted

    @property
    def name(self):
        """
        Gets the name of this HierarchyOutputV1.
        The human readable name

        :return: The name of this HierarchyOutputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this HierarchyOutputV1.
        The human readable name

        :param name: The name of this HierarchyOutputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def scoped_to(self):
        """
        Gets the scoped_to of this HierarchyOutputV1.
        The ID of the workbook to which the hierarchy is scoped. If not present, the hierarchy is globally scoped

        :return: The scoped_to of this HierarchyOutputV1.
        :rtype: str
        """
        return self._scoped_to

    @scoped_to.setter
    def scoped_to(self, scoped_to):
        """
        Sets the scoped_to of this HierarchyOutputV1.
        The ID of the workbook to which the hierarchy is scoped. If not present, the hierarchy is globally scoped

        :param scoped_to: The scoped_to of this HierarchyOutputV1.
        :type: str
        """

        self._scoped_to = scoped_to

    @property
    def status_message(self):
        """
        Gets the status_message of this HierarchyOutputV1.
        A plain language status message with information about any issues that may have been encountered during an operation

        :return: The status_message of this HierarchyOutputV1.
        :rtype: str
        """
        return self._status_message

    @status_message.setter
    def status_message(self, status_message):
        """
        Sets the status_message of this HierarchyOutputV1.
        A plain language status message with information about any issues that may have been encountered during an operation

        :param status_message: The status_message of this HierarchyOutputV1.
        :type: str
        """

        self._status_message = status_message

    @property
    def table_definition(self):
        """
        Gets the table_definition of this HierarchyOutputV1.

        :return: The table_definition of this HierarchyOutputV1.
        :rtype: ItemPreviewV1
        """
        return self._table_definition

    @table_definition.setter
    def table_definition(self, table_definition):
        """
        Sets the table_definition of this HierarchyOutputV1.

        :param table_definition: The table_definition of this HierarchyOutputV1.
        :type: ItemPreviewV1
        """
        if table_definition is None:
            raise ValueError("Invalid value for `table_definition`, must not be `None`")

        self._table_definition = table_definition

    @property
    def table_definition_output(self):
        """
        Gets the table_definition_output of this HierarchyOutputV1.

        :return: The table_definition_output of this HierarchyOutputV1.
        :rtype: TableDefinitionOutputV1
        """
        return self._table_definition_output

    @table_definition_output.setter
    def table_definition_output(self, table_definition_output):
        """
        Sets the table_definition_output of this HierarchyOutputV1.

        :param table_definition_output: The table_definition_output of this HierarchyOutputV1.
        :type: TableDefinitionOutputV1
        """
        if table_definition_output is None:
            raise ValueError("Invalid value for `table_definition_output`, must not be `None`")

        self._table_definition_output = table_definition_output

    @property
    def translation_key(self):
        """
        Gets the translation_key of this HierarchyOutputV1.
        The item's translation key, if any

        :return: The translation_key of this HierarchyOutputV1.
        :rtype: str
        """
        return self._translation_key

    @translation_key.setter
    def translation_key(self, translation_key):
        """
        Sets the translation_key of this HierarchyOutputV1.
        The item's translation key, if any

        :param translation_key: The translation_key of this HierarchyOutputV1.
        :type: str
        """

        self._translation_key = translation_key

    @property
    def type(self):
        """
        Gets the type of this HierarchyOutputV1.
        The type of the item

        :return: The type of this HierarchyOutputV1.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this HierarchyOutputV1.
        The type of the item

        :param type: The type of this HierarchyOutputV1.
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")

        self._type = type

    @property
    def view_columns(self):
        """
        Gets the view_columns of this HierarchyOutputV1.
        View Columns for the Table that correspond to Column Definitions. They contain grouping, filtering and sorting information for a given Hierarchy view applied to an Item Table.

        :return: The view_columns of this HierarchyOutputV1.
        :rtype: list[ViewColumnOutputV1]
        """
        return self._view_columns

    @view_columns.setter
    def view_columns(self, view_columns):
        """
        Sets the view_columns of this HierarchyOutputV1.
        View Columns for the Table that correspond to Column Definitions. They contain grouping, filtering and sorting information for a given Hierarchy view applied to an Item Table.

        :param view_columns: The view_columns of this HierarchyOutputV1.
        :type: list[ViewColumnOutputV1]
        """
        if view_columns is None:
            raise ValueError("Invalid value for `view_columns`, must not be `None`")

        self._view_columns = view_columns

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, HierarchyOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.2-v202604030243-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class SimpleTableInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'columns_to_include': 'list[str]',
        'include_ancestors': 'bool',
        'limit': 'int',
        'properties_to_include': 'list[PropertiesForItemUUIDColumn]',
        'search_input': 'TableSearchInputV1',
        'table_formulas': 'list[TableFormula]'
    }

    attribute_map = {
        'columns_to_include': 'columnsToInclude',
        'include_ancestors': 'includeAncestors',
        'limit': 'limit',
        'properties_to_include': 'propertiesToInclude',
        'search_input': 'searchInput',
        'table_formulas': 'tableFormulas'
    }

    def __init__(self, columns_to_include=None, include_ancestors=None, limit=None, properties_to_include=None, search_input=None, table_formulas=None):
        """
        SimpleTableInputV1 - a model defined in Swagger
        """

        self._columns_to_include = None
        self._include_ancestors = None
        self._limit = None
        self._properties_to_include = None
        self._search_input = None
        self._table_formulas = None

        if columns_to_include is not None:
          self.columns_to_include = columns_to_include
        if include_ancestors is not None:
          self.include_ancestors = include_ancestors
        if limit is not None:
          self.limit = limit
        if properties_to_include is not None:
          self.properties_to_include = properties_to_include
        if search_input is not None:
          self.search_input = search_input
        if table_formulas is not None:
          self.table_formulas = table_formulas

    @property
    def columns_to_include(self):
        """
        Gets the columns_to_include of this SimpleTableInputV1.
        What columns to include in the result. If set to null or not provided, all columns are returned. To include context columns, prepend the column with either 'context_comments.', 'context_label.', or 'context_opaque.' Ancestor level columns should not be included, use the includeAncestors boolean to include those if desired.

        :return: The columns_to_include of this SimpleTableInputV1.
        :rtype: list[str]
        """
        return self._columns_to_include

    @columns_to_include.setter
    def columns_to_include(self, columns_to_include):
        """
        Sets the columns_to_include of this SimpleTableInputV1.
        What columns to include in the result. If set to null or not provided, all columns are returned. To include context columns, prepend the column with either 'context_comments.', 'context_label.', or 'context_opaque.' Ancestor level columns should not be included, use the includeAncestors boolean to include those if desired.

        :param columns_to_include: The columns_to_include of this SimpleTableInputV1.
        :type: list[str]
        """

        self._columns_to_include = columns_to_include

    @property
    def include_ancestors(self):
        """
        Gets the include_ancestors of this SimpleTableInputV1.
        Boolean for if search ancestor columns should be generated and returned

        :return: The include_ancestors of this SimpleTableInputV1.
        :rtype: bool
        """
        return self._include_ancestors

    @include_ancestors.setter
    def include_ancestors(self, include_ancestors):
        """
        Sets the include_ancestors of this SimpleTableInputV1.
        Boolean for if search ancestor columns should be generated and returned

        :param include_ancestors: The include_ancestors of this SimpleTableInputV1.
        :type: bool
        """

        self._include_ancestors = include_ancestors

    @property
    def limit(self):
        """
        Gets the limit of this SimpleTableInputV1.
        Maximum number of rows to return

        :return: The limit of this SimpleTableInputV1.
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """
        Sets the limit of this SimpleTableInputV1.
        Maximum number of rows to return

        :param limit: The limit of this SimpleTableInputV1.
        :type: int
        """
        if limit is None:
            raise ValueError("Invalid value for `limit`, must not be `None`")

        self._limit = limit

    @property
    def properties_to_include(self):
        """
        Gets the properties_to_include of this SimpleTableInputV1.
        Additional properties to fetch per row that will be added as additional columns. The following columns can be used:  item id,  Asset,  Path,  Value UOM,  Datasource,  Source Column ID  Ancestor level columns should not be included, use the includeAncestors boolean to include those if desired.

        :return: The properties_to_include of this SimpleTableInputV1.
        :rtype: list[PropertiesForItemUUIDColumn]
        """
        return self._properties_to_include

    @properties_to_include.setter
    def properties_to_include(self, properties_to_include):
        """
        Sets the properties_to_include of this SimpleTableInputV1.
        Additional properties to fetch per row that will be added as additional columns. The following columns can be used:  item id,  Asset,  Path,  Value UOM,  Datasource,  Source Column ID  Ancestor level columns should not be included, use the includeAncestors boolean to include those if desired.

        :param properties_to_include: The properties_to_include of this SimpleTableInputV1.
        :type: list[PropertiesForItemUUIDColumn]
        """

        self._properties_to_include = properties_to_include

    @property
    def search_input(self):
        """
        Gets the search_input of this SimpleTableInputV1.

        :return: The search_input of this SimpleTableInputV1.
        :rtype: TableSearchInputV1
        """
        return self._search_input

    @search_input.setter
    def search_input(self, search_input):
        """
        Sets the search_input of this SimpleTableInputV1.

        :param search_input: The search_input of this SimpleTableInputV1.
        :type: TableSearchInputV1
        """
        if search_input is None:
            raise ValueError("Invalid value for `search_input`, must not be `None`")

        self._search_input = search_input

    @property
    def table_formulas(self):
        """
        Gets the table_formulas of this SimpleTableInputV1.
        The formulas to run against the items in the table results. Each formula result will be returned as their own column in the order requested by the formula. ColumnsToInclude must include the column containing the items to run the formula across.

        :return: The table_formulas of this SimpleTableInputV1.
        :rtype: list[TableFormula]
        """
        return self._table_formulas

    @table_formulas.setter
    def table_formulas(self, table_formulas):
        """
        Sets the table_formulas of this SimpleTableInputV1.
        The formulas to run against the items in the table results. Each formula result will be returned as their own column in the order requested by the formula. ColumnsToInclude must include the column containing the items to run the formula across.

        :param table_formulas: The table_formulas of this SimpleTableInputV1.
        :type: list[TableFormula]
        """

        self._table_formulas = table_formulas

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, SimpleTableInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.2-v202604030243-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ScheduledNotebookResultInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _error: Optional[str]
    _run_started_at: str
    _run_time: Optional[int]
    _warning: Optional[str]


    def __init__(
        self,
        error: Optional[str] = None,
        run_started_at: Optional[str] = None,
        run_time: Optional[int] = None,
        warning: Optional[str] = None,
    ) -> None: ...

    @property
    def error(self) -> Optional[str]: ...

    @error.setter
    def error(self, error: Optional[str]) -> None: ...

    @property
    def run_started_at(self) -> str: ...

    @run_started_at.setter
    def run_started_at(self, run_started_at: str) -> None: ...

    @property
    def run_time(self) -> Optional[int]: ...

    @run_time.setter
    def run_time(self, run_time: Optional[int]) -> None: ...

    @property
    def warning(self) -> Optional[str]: ...

    @warning.setter
    def warning(self, warning: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.2-v202604030243-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class AddOnInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _add_on_components: Optional[str]
    _add_on_identifier: str
    _description: Optional[str]
    _enabled: Optional[bool]
    _in_development: Optional[bool]
    _name: str
    _version_string: Optional[str]


    def __init__(
        self,
        add_on_components: Optional[str] = None,
        add_on_identifier: Optional[str] = None,
        description: Optional[str] = None,
        enabled: Optional[bool] = True,
        in_development: Optional[bool] = False,
        name: Optional[str] = None,
        version_string: Optional[str] = None,
    ) -> None: ...

    @property
    def add_on_components(self) -> Optional[str]: ...

    @add_on_components.setter
    def add_on_components(self, add_on_components: Optional[str]) -> None: ...

    @property
    def add_on_identifier(self) -> str: ...

    @add_on_identifier.setter
    def add_on_identifier(self, add_on_identifier: str) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def enabled(self) -> Optional[bool]: ...

    @enabled.setter
    def enabled(self, enabled: Optional[bool]) -> None: ...

    @property
    def in_development(self) -> Optional[bool]: ...

    @in_development.setter
    def in_development(self, in_development: Optional[bool]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def version_string(self) -> Optional[str]: ...

    @version_string.setter
    def version_string(self, version_string: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.2-v202604030243-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ConfigurationOptionInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'note': 'str',
        'path': 'str',
        'value': 'object'
    }

    attribute_map = {
        'note': 'note',
        'path': 'path',
        'value': 'value'
    }

    def __init__(self, note=None, path=None, value=None):
        """
        ConfigurationOptionInputV1 - a model defined in Swagger
        """

        self._note = None
        self._path = None
        self._value = None

        if note is not None:
          self.note = note
        if path is not None:
          self.path = path
        if value is not None:
          self.value = value

    @property
    def note(self):
        """
        Gets the note of this ConfigurationOptionInputV1.
        A plain text note to provide context on the configuration change.

        :return: The note of this ConfigurationOptionInputV1.
        :rtype: str
        """
        return self._note

    @note.setter
    def note(self, note):
        """
        Sets the note of this ConfigurationOptionInputV1.
        A plain text note to provide context on the configuration change.

        :param note: The note of this ConfigurationOptionInputV1.
        :type: str
        """

        self._note = note

    @property
    def path(self):
        """
        Gets the path of this ConfigurationOptionInputV1.
        The unique identifier of the configuration option. Slashes in the path imply a hierarchy.

        :return: The path of this ConfigurationOptionInputV1.
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """
        Sets the path of this ConfigurationOptionInputV1.
        The unique identifier of the configuration option. Slashes in the path imply a hierarchy.

        :param path: The path of this ConfigurationOptionInputV1.
        :type: str
        """
        if path is None:
            raise ValueError("Invalid value for `path`, must not be `None`")

        self._path = path

    @property
    def value(self):
        """
        Gets the value of this ConfigurationOptionInputV1.
        The new value to set for this option. If omitted, the default value will be used.

        :return: The value of this ConfigurationOptionInputV1.
        :rtype: object
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this ConfigurationOptionInputV1.
        The new value to set for this option. If omitted, the default value will be used.

        :param value: The value of this ConfigurationOptionInputV1.
        :type: object
        """

        self._value = value

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ConfigurationOptionInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.2-v202604030243-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class MediaType(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _parameters: Optional[Dict[str, str]]
    _subtype: Optional[str]
    _type: Optional[str]
    _wildcard_subtype: Optional[bool]
    _wildcard_type: Optional[bool]


    def __init__(
        self,
        parameters: Optional[Dict[str, str]] = None,
        subtype: Optional[str] = None,
        type: Optional[str] = None,
        wildcard_subtype: Optional[bool] = None,
        wildcard_type: Optional[bool] = None,
    ) -> None: ...

    @property
    def parameters(self) -> Optional[Dict[str, str]]: ...

    @parameters.setter
    def parameters(self, parameters: Optional[Dict[str, str]]) -> None: ...

    @property
    def subtype(self) -> Optional[str]: ...

    @subtype.setter
    def subtype(self, subtype: Optional[str]) -> None: ...

    @property
    def type(self) -> Optional[str]: ...

    @type.setter
    def type(self, type: Optional[str]) -> None: ...

    @property
    def wildcard_subtype(self) -> Optional[bool]: ...

    @wildcard_subtype.setter
    def wildcard_subtype(self, wildcard_subtype: Optional[bool]) -> None: ...

    @property
    def wildcard_type(self) -> Optional[bool]: ...

    @wildcard_type.setter
    def wildcard_type(self, wildcard_type: Optional[bool]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.2-v202604030243-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class CustomAgentSummaryOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _created_at: str
    _draft: CustomAgentDraftInfoOutputV1
    _effective_permissions: Optional[PermissionsV1]
    _id: str
    _name: str
    _owner: Optional[bool]
    _updated_at: str


    def __init__(
        self,
        created_at: Optional[str] = None,
        draft: Optional[CustomAgentDraftInfoOutputV1] = None,
        effective_permissions: Optional[PermissionsV1] = None,
        id: Optional[str] = None,
        name: Optional[str] = None,
        owner: Optional[bool] = None,
        updated_at: Optional[str] = None,
    ) -> None: ...

    @property
    def created_at(self) -> str: ...

    @created_at.setter
    def created_at(self, created_at: str) -> None: ...

    @property
    def draft(self) -> CustomAgentDraftInfoOutputV1: ...

    @draft.setter
    def draft(self, draft: CustomAgentDraftInfoOutputV1) -> None: ...

    @property
    def effective_permissions(self) -> Optional[PermissionsV1]: ...

    @effective_permissions.setter
    def effective_permissions(self, effective_permissions: Optional[PermissionsV1]) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def owner(self) -> Optional[bool]: ...

    @owner.setter
    def owner(self, owner: Optional[bool]) -> None: ...

    @property
    def updated_at(self) -> str: ...

    @updated_at.setter
    def updated_at(self, updated_at: str) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.2-v202604030243-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ContextPermissionDeniedOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'error_code': 'str',
        'item_id': 'str',
        'permission_type': 'str',
        'status_message': 'str',
        'table_id': 'str'
    }

    attribute_map = {
        'error_code': 'errorCode',
        'item_id': 'itemId',
        'permission_type': 'permissionType',
        'status_message': 'statusMessage',
        'table_id': 'tableId'
    }

    def __init__(self, error_code=None, item_id=None, permission_type=None, status_message=None, table_id=None):
        """
        ContextPermissionDeniedOutputV1 - a model defined in Swagger
        """

        self._error_code = None
        self._item_id = None
        self._permission_type = None
        self._status_message = None
        self._table_id = None

        if error_code is not None:
          self.error_code = error_code
        if item_id is not None:
          self.item_id = item_id
        if permission_type is not None:
          self.permission_type = permission_type
        if status_message is not None:
          self.status_message = status_message
        if table_id is not None:
          self.table_id = table_id

    @property
    def error_code(self):
        """
        Gets the error_code of this ContextPermissionDeniedOutputV1.
        Stable error code for context permission failures

        :return: The error_code of this ContextPermissionDeniedOutputV1.
        :rtype: str
        """
        return self._error_code

    @error_code.setter
    def error_code(self, error_code):
        """
        Sets the error_code of this ContextPermissionDeniedOutputV1.
        Stable error code for context permission failures

        :param error_code: The error_code of this ContextPermissionDeniedOutputV1.
        :type: str
        """

        self._error_code = error_code

    @property
    def item_id(self):
        """
        Gets the item_id of this ContextPermissionDeniedOutputV1.
        The item that the user did not have permission to access

        :return: The item_id of this ContextPermissionDeniedOutputV1.
        :rtype: str
        """
        return self._item_id

    @item_id.setter
    def item_id(self, item_id):
        """
        Sets the item_id of this ContextPermissionDeniedOutputV1.
        The item that the user did not have permission to access

        :param item_id: The item_id of this ContextPermissionDeniedOutputV1.
        :type: str
        """

        self._item_id = item_id

    @property
    def permission_type(self):
        """
        Gets the permission_type of this ContextPermissionDeniedOutputV1.
        The permission that was required to complete the request

        :return: The permission_type of this ContextPermissionDeniedOutputV1.
        :rtype: str
        """
        return self._permission_type

    @permission_type.setter
    def permission_type(self, permission_type):
        """
        Sets the permission_type of this ContextPermissionDeniedOutputV1.
        The permission that was required to complete the request

        :param permission_type: The permission_type of this ContextPermissionDeniedOutputV1.
        :type: str
        """

        self._permission_type = permission_type

    @property
    def status_message(self):
        """
        Gets the status_message of this ContextPermissionDeniedOutputV1.
        A plain language status message with information about any issues that may have been encountered during an operation. Null if the status message has not been set.

        :return: The status_message of this ContextPermissionDeniedOutputV1.
        :rtype: str
        """
        return self._status_message

    @status_message.setter
    def status_message(self, status_message):
        """
        Sets the status_message of this ContextPermissionDeniedOutputV1.
        A plain language status message with information about any issues that may have been encountered during an operation. Null if the status message has not been set.

        :param status_message: The status_message of this ContextPermissionDeniedOutputV1.
        :type: str
        """

        self._status_message = status_message

    @property
    def table_id(self):
        """
        Gets the table_id of this ContextPermissionDeniedOutputV1.
        The table that also required permissions, when applicable

        :return: The table_id of this ContextPermissionDeniedOutputV1.
        :rtype: str
        """
        return self._table_id

    @table_id.setter
    def table_id(self, table_id):
        """
        Sets the table_id of this ContextPermissionDeniedOutputV1.
        The table that also required permissions, when applicable

        :param table_id: The table_id of this ContextPermissionDeniedOutputV1.
        :type: str
        """

        self._table_id = table_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ContextPermissionDeniedOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.2-v202604030243-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class HierarchyInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _alias_column_id: Optional[str]
    _description: Optional[str]
    _filter_grouping: Optional[str]
    _name: str
    _scoped_to: Optional[str]
    _table_definition_id: Optional[str]
    _view_columns: List[ViewColumnInputV1]


    def __init__(
        self,
        alias_column_id: Optional[str] = None,
        description: Optional[str] = None,
        filter_grouping: Optional[str] = None,
        name: Optional[str] = None,
        scoped_to: Optional[str] = None,
        table_definition_id: Optional[str] = None,
        view_columns: Optional[List[ViewColumnInputV1]] = None,
    ) -> None: ...

    @property
    def alias_column_id(self) -> Optional[str]: ...

    @alias_column_id.setter
    def alias_column_id(self, alias_column_id: Optional[str]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def filter_grouping(self) -> Optional[str]: ...

    @filter_grouping.setter
    def filter_grouping(self, filter_grouping: Optional[str]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def scoped_to(self) -> Optional[str]: ...

    @scoped_to.setter
    def scoped_to(self, scoped_to: Optional[str]) -> None: ...

    @property
    def table_definition_id(self) -> Optional[str]: ...

    @table_definition_id.setter
    def table_definition_id(self, table_definition_id: Optional[str]) -> None: ...

    @property
    def view_columns(self) -> List[ViewColumnInputV1]: ...

    @view_columns.setter
    def view_columns(self, view_columns: List[ViewColumnInputV1]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.2-v202604030243-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class PropertiesForItemUUIDColumn(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'property_names': 'list[str]',
        'uuid_column': 'str'
    }

    attribute_map = {
        'property_names': 'propertyNames',
        'uuid_column': 'uuidColumn'
    }

    def __init__(self, property_names=None, uuid_column=None):
        """
        PropertiesForItemUUIDColumn - a model defined in Swagger
        """

        self._property_names = None
        self._uuid_column = None

        if property_names is not None:
          self.property_names = property_names
        if uuid_column is not None:
          self.uuid_column = uuid_column

    @property
    def property_names(self):
        """
        Gets the property_names of this PropertiesForItemUUIDColumn.
        The name of the property to return for the item

        :return: The property_names of this PropertiesForItemUUIDColumn.
        :rtype: list[str]
        """
        return self._property_names

    @property_names.setter
    def property_names(self, property_names):
        """
        Sets the property_names of this PropertiesForItemUUIDColumn.
        The name of the property to return for the item

        :param property_names: The property_names of this PropertiesForItemUUIDColumn.
        :type: list[str]
        """

        self._property_names = property_names

    @property
    def uuid_column(self):
        """
        Gets the uuid_column of this PropertiesForItemUUIDColumn.
        The name of the UUID column whose item property should be returned

        :return: The uuid_column of this PropertiesForItemUUIDColumn.
        :rtype: str
        """
        return self._uuid_column

    @uuid_column.setter
    def uuid_column(self, uuid_column):
        """
        Sets the uuid_column of this PropertiesForItemUUIDColumn.
        The name of the UUID column whose item property should be returned

        :param uuid_column: The uuid_column of this PropertiesForItemUUIDColumn.
        :type: str
        """

        self._uuid_column = uuid_column

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, PropertiesForItemUUIDColumn):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.2-v202604030243-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class AssetGroupTreeOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _children: Optional[List[AssetGroupTreeOutputV1]]
    _datasource_id: Optional[str]
    _description: Optional[str]
    _item: Optional[ItemPreviewWithAssetsV1]
    _parameters: Optional[List[FormulaParameterOutputV1]]


    def __init__(
        self,
        children: Optional[List[AssetGroupTreeOutputV1]] = None,
        datasource_id: Optional[str] = None,
        description: Optional[str] = None,
        item: Optional[ItemPreviewWithAssetsV1] = None,
        parameters: Optional[List[FormulaParameterOutputV1]] = None,
    ) -> None: ...

    @property
    def children(self) -> Optional[List[AssetGroupTreeOutputV1]]: ...

    @children.setter
    def children(self, children: Optional[List[AssetGroupTreeOutputV1]]) -> None: ...

    @property
    def datasource_id(self) -> Optional[str]: ...

    @datasource_id.setter
    def datasource_id(self, datasource_id: Optional[str]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def item(self) -> Optional[ItemPreviewWithAssetsV1]: ...

    @item.setter
    def item(self, item: Optional[ItemPreviewWithAssetsV1]) -> None: ...

    @property
    def parameters(self) -> Optional[List[FormulaParameterOutputV1]]: ...

    @parameters.setter
    def parameters(self, parameters: Optional[List[FormulaParameterOutputV1]]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.2-v202604030243-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class FormulaErrorOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _column: Optional[int]
    _error_category: Optional[str]
    _error_type: Optional[str]
    _line: Optional[int]
    _message: Optional[str]
    _status_message: Optional[str]


    def __init__(
        self,
        column: Optional[int] = None,
        error_category: Optional[str] = None,
        error_type: Optional[str] = None,
        line: Optional[int] = None,
        message: Optional[str] = None,
        status_message: Optional[str] = None,
    ) -> None: ...

    @property
    def column(self) -> Optional[int]: ...

    @column.setter
    def column(self, column: Optional[int]) -> None: ...

    @property
    def error_category(self) -> Optional[str]: ...

    @error_category.setter
    def error_category(self, error_category: Optional[str]) -> None: ...

    @property
    def error_type(self) -> Optional[str]: ...

    @error_type.setter
    def error_type(self, error_type: Optional[str]) -> None: ...

    @property
    def line(self) -> Optional[int]: ...

    @line.setter
    def line(self, line: Optional[int]) -> None: ...

    @property
    def message(self) -> Optional[str]: ...

    @message.setter
    def message(self, message: Optional[str]) -> None: ...

    @property
    def status_message(self) -> Optional[str]: ...

    @status_message.setter
    def status_message(self, status_message: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
